@@ -22,7 +22,7 @@
 #ifndef __GLIBTOP_SAFEIO_H__
 #define __GLIBTOP_SAFEIO_H__
 
-#include <glib/gmacros.h>
+#include <glib.h>
 
 #include <sys/types.h>
 #include <sys/stat.h>
