@@ -31,7 +31,7 @@ static const unsigned long _glibtop_sysdeps_proclist = 0;
 /* Init function. */
 
 void
-glibtop_init_proclist_p (glibtop *server)
+_glibtop_init_proclist_p (glibtop *server)
 {
 	server->sysdeps.proclist = _glibtop_sysdeps_proclist;
 }
